## Versatile Data Kit Server Plugin

This plugin facilitates installation of the Control Service in a local [Kind](https://kind.sigs.k8s.io/) cluster.

### Usage

To use the plugin, just install it using:
```bash
pip install vdk-server
```

To install the Control Service:
```bash
vdk server --install
```

To remove revious installation:
```bash
vdk server --uninstall
```
